import 'dart:collection';
import 'package:analyzer/dart/element/element.dart' as ele;
import 'entity.dart';
import 'json2dart/model_generator.dart';
import 'package:source_gen/source_gen.dart';
import 'package:build/build.dart';
import 'dart:io';
import 'tpl/tpl.dart' as tpl;

class EntityGenerator extends GeneratorForAnnotation<GEntity> {
  static final separator = Platform.pathSeparator;
  static final Map entityMap = Map();
  static final Map importMap = Map();

  static final EntityGenerator _instance = EntityGenerator._internal();

  factory EntityGenerator() => _instance;

  EntityGenerator._internal();

  String buildCode(map) {
    var sb = StringBuffer();
    SplayTreeMap st = SplayTreeMap.from(map);
    st.forEach((key, value) {
      sb.writeln("      case '$key': return $key.fromJson(json) as T;");
    });
    return sb.toString();
  }

  String buildImport(map) {
    var sb = StringBuffer();
    SplayTreeMap st = SplayTreeMap.from(map);
    st.forEach((key, value) {
      sb.writeln("import '$key';");
    });
    return sb.toString();
  }

  String buildDart(className, jsonRawData, importList, auto) {
    var sb = StringBuffer();
    importList.forEach((v) {
      sb.writeln(v);
    });
    sb.writeln();
    sb.write(tpl.annoTpl(buildJson: jsonRawData, auto: !auto));
    sb.writeln(
        ModelGenerator(className, false).generateDartClasses(jsonRawData).code);
    return sb.toString();
  }

  @override
  generateForAnnotatedElement(
      ele.Element element, ConstantReader annotation, BuildStep buildStep) {
    entityMap[element.name] = null;
    String jsonStr = "";
    bool auto = false;
    var enable = false;
    try {
      enable = annotation.read('enable').boolValue;
    } catch (e) {}
    if (!enable) return null;
    try {
      jsonStr = annotation.read('json').stringValue.trim();
    } catch (e) {}
    try {
      auto = annotation.read('auto').boolValue;
    } catch (e) {}
    if (buildStep.inputId.path.contains('lib/')) {
      var path = buildStep.inputId.path;
      importMap[
              "package:${buildStep.inputId.package}/${path.replaceFirst('lib/', '')}"] =
          null;
    }
    File(
        '${Directory.current.path}${separator}lib${separator}api${separator}entity${separator}entity_factory.entity.dart')
      ..createSync(recursive: true)
      ..writeAsStringSync(
        tpl.clazzTpl(
            buildCode: buildCode(entityMap),
            buildImport: buildImport(importMap)),
        flush: true,
      );
    if (auto && jsonStr.length > 0) {
      var importList = [
        "import 'package:xanno/xanno.dart';",
      ];
      var path = buildStep.inputId.path;
      var filePath = '${Directory.current.path}$separator$path';
      File(filePath).writeAsStringSync(
          buildDart(element.name, jsonStr, importList, auto),
          flush: true);
    }
    return null;
  }
}

Builder entityBuilder(BuilderOptions options) =>
    LibraryBuilder(EntityGenerator(), generatedExtension: ".entity.dart");
